# Instractions 

#### This is our test project.
#### Please install this package
```
pip install functions-by-krinatova
```



#### You can also install older packages
```
pip install functions-by-krinatova==VERSION_NUMBER
```